@@ -43,9 +43,6 @@ class Config:
 		self.user = ""
 		self.password = ""
 		self.color = ""
-		self.lastfm_user = ""
-		self.lastfm_password = ""
-		self.lastfm_scrobble_percent = "50"
 		self.control_proxy = ""
 		self.act_help = "?"
 		self.act_songlove = "+"
@@ -68,7 +65,8 @@ class Config:
 		self.act_stationselectquickmix = "x"
 		self.audio_format = "mp3"
 		self.autostart_station = ""
-		self.config_opts = ['user','password','lastfm_user','lastfm_password','lastfm_scrobble_percent',
+		self.lastplayed = ""
+		self.config_opts = ['user','password',
 			'control_proxy','act_help','act_songlove','act_songban', 'act_stationaddmusic',
 			'act_stationcreate', 'act_stationdelete', 'act_songexplain', 'act_stationaddbygenre',
 			'act_songinfo', 'act_addshared', 'act_songmove', 'act_songpause', 'act_quit', 
@@ -101,6 +99,10 @@ class Config:
 					if re.match("^"+opt+"=(.+)$",line) is not None:
 						setattr(self,opt,self.get_var(opt,line))
 			f.close()
+		if os.path.exists(os.path.expanduser("~")+'/.config/pianobar/lastplayed'):
+			f = open(os.path.expanduser("~")+'/.config/pianobar/lastplayed', 'r')
+			self.lastplayed = f.readline().replace("\n","")
+			f.close()
 		
 	def write(self):
 		newfile = ""
@@ -112,10 +114,6 @@ class Config:
 					newfile+="user="+self.user+"\n"
 				elif len(self.password)>0 and re.match("#*password=",line) is not None:
 					newfile+="password="+self.password+"\n"
-				elif len(self.lastfm_user)>0 and re.match("#*lastfm_user=",line) is not None:
-					newfile+="lastfm_user="+self.lastfm_user+"\n"
-				elif len(self.lastfm_password)>0 and re.match("#*lastfm_password=",line) is not None:
-					newfile+="lastfm_password="+self.lastfm_password+"\n"
 				else:
 					newfile+=line
 			f.close()
@@ -154,7 +152,7 @@ class snooze(QtCore.QThread):
 		
 class tPandora(QtCore.QThread):
 
-	__pyqtSignals__ = ( "stations","newsong", "showUsername", "showPassword", "oops", "second" )
+	__pyqtSignals__ = ( "stations","newsong", "showUsername", "showPassword", "oops", "second", "autoPlay" )
 
 	def __init__(self, c):
 		self.sTitle = ""
@@ -185,6 +183,10 @@ class tPandora(QtCore.QThread):
 			if re.match(".+Password$",newline) is not None:
 				self.emit(QtCore.SIGNAL("showPassword"), self.sTitle)
 				self.last = "password"
+
+			if re.match(".+Select station: $",newline) is not None:
+				if not self.last == "quickswitch":
+					self.emit(QtCore.SIGNAL("autoPlay"), self.sTitle)
 			
 			elif char == "\n":
 				output = newline.split("|>")
@@ -218,8 +220,9 @@ class tPandora(QtCore.QThread):
 							self.stations[int(stations.group(1))] = station
 						else:
 							self.stations.append(station)
-
-						self.last = "stations"	
+						
+						if not self.last == "quickswitch":
+							self.last = "stations"
 						self.emit(QtCore.SIGNAL("stations"), self.sTitle)
 						
 					
@@ -263,6 +266,7 @@ class MyForm(QtGui.QMainWindow):
 		QtCore.QObject.connect(self.p, QtCore.SIGNAL('oops'), self.doError)
 		QtCore.QObject.connect(self.p, QtCore.SIGNAL('showUsername'), self.showUsername)
 		QtCore.QObject.connect(self.p, QtCore.SIGNAL('showPassword'), self.showPassword)
+		QtCore.QObject.connect(self.p, QtCore.SIGNAL('autoPlay'), self.autoPlay)
 		QtCore.QObject.connect(self.p, QtCore.SIGNAL('second'), self.uSecond)
 		QtCore.QObject.connect(self.s, QtCore.SIGNAL('shutdown'), self.sQuit)
 		QtCore.QObject.connect(self.a, QtCore.SIGNAL('album'), self.uAlbum)
@@ -272,7 +276,6 @@ class MyForm(QtGui.QMainWindow):
 		QtCore.QObject.connect(self.ui.btnPlay, QtCore.SIGNAL('clicked()'), self.doPlayPause)
 		QtCore.QObject.connect(self.ui.btnSleep, QtCore.SIGNAL('clicked()'), self.tiredSong)
 		QtCore.QObject.connect(self.ui.actionUser_Pass, QtCore.SIGNAL('triggered()'), self.setUserPass)
-		QtCore.QObject.connect(self.ui.actionLastfm_User_Pass, QtCore.SIGNAL('triggered()'), self.setLastfm)
 		QtCore.QObject.connect(self.ui.actionDelete, QtCore.SIGNAL('triggered()'), self.deleteStation)
 		QtCore.QObject.connect(self.ui.actionCreate, QtCore.SIGNAL('triggered()'), self.createStation)
 		QtCore.QObject.connect(self.ui.actionSnooze, QtCore.SIGNAL('triggered()'), self.setSnooze)
@@ -282,11 +285,21 @@ class MyForm(QtGui.QMainWindow):
 		QtCore.QObject.connect(self.ui.btnSleep, QtCore.SIGNAL('released()'), self.sleepUp)
 		QtCore.QObject.connect(self.ui.btnHate, QtCore.SIGNAL('pressed()'), self.hateDown)
 		QtCore.QObject.connect(self.ui.btnHate, QtCore.SIGNAL('released()'), self.hateUp)
-
-
 		QtCore.QObject.connect(self.ui.listStations, QtCore.SIGNAL('activated(int)'), self.setStation)
 		QtCore.QObject.connect(self, QtCore.SIGNAL('triggered()'), self.closeEvent)
 
+	def autoPlay(self):
+		i = -1
+		self.station = i
+		for station in self.p.stations:
+			i = i + 1
+			if self.c.lastplayed == station:
+				self.station = i
+		if not self.station == -1:
+			self.p.pandora.stdin.write(str(self.station)+"\n")
+			self.ui.btnPlay.setStyleSheet("background-color: "+ self.c.color + ";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/playing-trans.png);")
+			self.ui.listStations.setCurrentIndex(self.station)
+
 	def setUserPass(self):
 		self.showUsername()
 		self.showPassword()
@@ -342,16 +355,22 @@ class MyForm(QtGui.QMainWindow):
 			self.p.pandora.stdin.write(self.c.act_stationchange)
 		else:
 			if self.p.last == "song":
+				self.p.last = "quickswitch"
 				self.p.pandora.stdin.write(self.c.act_stationchange)
 		
 			self.station = self.ui.listStations.currentIndex()
-			self.p.pandora.stdin.write(str(self.ui.listStations.currentIndex())+"\n")
+			self.p.pandora.stdin.write(str(self.station)+"\n")
 			self.ui.btnPlay.setStyleSheet("background-color: "+ self.c.color + ";\nborder: rgb(0, 0, 0);\nbackground-image: url(:/img/img/playing-trans.png);")
+			f = open(os.path.expanduser("~")+'/.config/pianobar/lastplayed', 'w')
+			f.write(self.ui.listStations.currentText())
+			f.close()
 
 	def tiredSong(self):
 		if self.p.last == "song":
-			self.p.pandora.stdin.write(self.c.act_songtired)
-	
+			check = QtGui.QMessageBox.question(self, 'Are you sure?', 'Are you tired of the song ' + self.p.sTitle + '?','No','Yes')
+			if check == 1:
+				self.p.pandora.stdin.write(self.c.act_songtired)
+			
 	def setSnooze(self):
 		time,ok = QtGui.QInputDialog.getText(self,"Snooze", "Enter a time, in minutes, to shutdown:")
 		if ok:
@@ -420,6 +439,9 @@ class MyForm(QtGui.QMainWindow):
 	def doPlayPause(self):
 		if self.p.last == "stations":
 			self.p.pandora.stdin.write(str(self.ui.listStations.currentIndex())+"\n")
+			f = open(os.path.expanduser("~")+'/.config/pianobar/lastplayed', 'w')
+			f.write(self.ui.listStations.currentText())
+			f.close()
 		else:
 			self.p.pandora.stdin.write(self.c.act_songpause)
 
@@ -467,15 +489,6 @@ class MyForm(QtGui.QMainWindow):
 	def doQuit(self):
 		quit()
 	
-	def setLastfm(self):
-		username,ok = QtGui.QInputDialog.getText(self,"Username", "Last.fm Username:",QLineEdit.Normal,self.c.lastfm_user)
-		if ok:
-			self.c.lastfm_user = username
-		password,ok =  QtGui.QInputDialog.getText(self,"Password", "Last.fm Password:",QLineEdit.Password)
-		if ok:
-			self.c.lastfm_password = password
-			self.c.write()
-
 	def showUsername(self):
 		username,ok = QtGui.QInputDialog.getText(self,"Username", "Pandora Username:", QLineEdit.Normal,self.c.user)
 		if ok:
